LinkTransformer

Trait LinkTransformer 

pub trait LinkTransformer: Debug + DynClone {
    // Required methods
    fn apply(&self, link: &mut Link<'_>) -> Result<()>;
    fn tag(&self) -> String;

    // Provided methods
    fn pattern(&self) -> Regex { ... }
    fn strip_tag(&self) -> bool { ... }
}
If a link transformer matches on a tag, it shall produce a meaningful regex-substituted transformation.

Required Methods

fn apply(&self, link: &mut Link<'_>) -> Result<()>

Apply the link transformation.

fn tag(&self) -> String

Text on which the link transformer can operate shall start with this string.

Provided Methods

fn pattern(&self) -> Regex

Regex which will be applied to extract the salient part of the link destination.

fn strip_tag(&self) -> bool

Implementors